UnixSeconds

Struct UnixSeconds 

pub struct UnixSeconds(/* private fields */);
Available on crate features fmt only.
A system time represented as the number of whole seconds since the Unix epoch.

Examples:

  • 0 is equal to Thu, 1 Jan 1970 00:00:00 -0000
  • 951786000 is equal to Tue, 29 Feb 2000 01:00:00 -0000

UTC and time zones

The seconds are always represented in the UTC time zone.

Serialization and deserialization

UnixSeconds implements the Serialize and Deserialize traits from the serde_core crate. The system time is serialized as whole seconds. Fractional seconds are rounded down.

The serialization support is available when serde feature is enabled.

Leap seconds

This value represents the number of non-leap seconds since the Unix epoch.

Examples

Parsing and formatting

This example demonstrates how to parse Unix seconds and convert them to SystemTime.

use std::time::{Duration, SystemTime};

use tick::fmt::UnixSeconds;

let unix_seconds = "9999".parse::<UnixSeconds>()?;
assert_eq!(unix_seconds.to_string(), "9999");

let system_time: SystemTime = unix_seconds.into();
assert_eq!(
    system_time,
    SystemTime::UNIX_EPOCH + Duration::from_secs(9999)
);

Implementations

Source

impl UnixSeconds

pub const MAX: Self

The largest value that be can represented by UnixSeconds.

This represents a Unix system time of 31 December 9999 23:59:59 UTC.

pub const UNIX_EPOCH: Self

The Unix epoch represented as UnixSeconds.

This represents a Unix system time of 1 January 1970 00:00:00 UTC.

pub fn from_secs(seconds: u64) -> Result<Self, Error>

Creates a new UnixSeconds from the given number of seconds since the Unix epoch.

Errors

Returns an error if the provided seconds are out of range.

use tick::fmt::UnixSeconds;

UnixSeconds::from_secs(u64::MAX).unwrap_err();
Examples
use std::time::{Duration, SystemTime};

use tick::fmt::UnixSeconds;

let unix_seconds = UnixSeconds::from_secs(10).unwrap();
let system_time: SystemTime = unix_seconds.into();

assert_eq!(
    system_time,
    SystemTime::UNIX_EPOCH + Duration::from_secs(10)
);
pub fn to_secs(self) -> u64

Returns the number of whole seconds since the Unix epoch.