pub struct Error(/* private fields */);Expand description
An error that can occur in the tick crate.
The most common type of error results from overflow, but other errors also exist:
- Parsing and formatting errors.
- Validation problems.
Limited introspection
Other than implementing the std::error::Error and core::fmt::Debug traits, this error type
currently provides no introspection capabilities.
Examples
use tick::Error;
use tick::fmt::Iso8601;
"invalid date".parse::<Iso8601>().unwrap_err();Trait Implementations
Sourceimpl Error for Error
impl Error for Error
Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()
Sourceimpl From<SystemTimeError> for Error
impl From<SystemTimeError> for Error
Sourcefn from(err: SystemTimeError) -> Self
fn from(err: SystemTimeError) -> Self
Converts to this type from the input type.
Sourceimpl ThreadAware for Error
impl ThreadAware for Error
Sourcefn relocated(
self,
_source: MemoryAffinity,
_destination: PinnedAffinity,
) -> Self
fn relocated( self, _source: MemoryAffinity, _destination: PinnedAffinity, ) -> Self
Consume a value and return a value in the destination affinity. Read more