PeriodicTimer

Struct PeriodicTimer 

pub struct PeriodicTimer { /* private fields */ }
A timer that periodically ticks.

A periodic timer can be created using the PeriodicTimer::new() constructor, which requires a reference to a Clock.

Precision

The timer uses the current thread’s scheduler to schedule its ticks. The precision of the timer is affected by the load on this thread. There are no guarantees about the precision of the timer other than that it will eventually tick. When the thread is healthy, the timer’s period should be close to the specified one.

Note: The periodic timer is not affected by adjustments to the system clock.

Stream Behavior

PeriodicTimer implements Stream and will never complete. The stream produces a tick every period indefinitely. Use stream combinators like StreamExt::take to limit the number of ticks.

Examples

Create a periodic timer

use std::time::Duration;

use futures::StreamExt;
use tick::{Clock, PeriodicTimer, Stopwatch};

let timer = PeriodicTimer::new(clock, Duration::from_millis(1));

timer
    .take(3)
    .for_each(async |()| {
        // Do something every 1ms
    })
    .await;

Create a periodic timer with initial delay

use std::time::Duration;

use futures::StreamExt;
use tick::{Clock, PeriodicTimer};

// Delay for 10ms before the timer starts ticking
clock.delay(Duration::from_millis(10)).await;

let timer = PeriodicTimer::new(clock, Duration::from_millis(1));

timer
    .take(3)
    .for_each(async |()| {
        // Do something every 1ms
    })
    .await;

Implementations

Source

impl PeriodicTimer

pub fn new(clock: &Clock, period: Duration) -> Self

Creates a timer that fires periodically.

Note: The minimum precision of the timer is 1ms. If a smaller period is specified, it will be adjusted to 1ms.